@@ -1,14 +1,10 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
 extern crate prost_build;
 
 fn main() {
+    // Setup protoc environment variable
+    #[cfg(target_family = "unix")]
+    std::env::set_var("PROTOC", protobuf_src::protoc());
+
     let mut prost_config = prost_build::Config::new();
     let outdir = concat!(env!("CARGO_MANIFEST_DIR"), "/src/proto/prost_gen");
     println!("outdir: {}", outdir);
