@@ -1,11 +1,3 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
 #[macro_use]
 extern crate lazy_static;
 
@@ -23,7 +15,7 @@ use tokio::runtime::Runtime;
 use vegafusion_core::data::scalar::ScalarValueHelpers;
 use vegafusion_core::data::table::VegaFusionTable;
 
-use vegafusion_core::planning::plan::SpecPlan;
+use vegafusion_core::planning::plan::{PlannerConfig, SpecPlan};
 
 use vegafusion_core::planning::watch::{
     ExportUpdate, ExportUpdateBatch, ExportUpdateNamespace, Watch, WatchNamespace, WatchPlan,
@@ -35,10 +27,12 @@ use vegafusion_core::spec::chart::ChartSpec;
 use vegafusion_core::task_graph::graph::ScopedVariable;
 use vegafusion_core::task_graph::task_value::TaskValue;
 use vegafusion_rt_datafusion::task_graph::runtime::TaskGraphRuntime;
+use vegafusion_rt_datafusion::tokio_runtime::TOKIO_THREAD_STACK_SIZE;
 
 lazy_static! {
     static ref TOKIO_RUNTIME: Runtime = tokio::runtime::Builder::new_multi_thread()
         .enable_all()
+        .thread_stack_size(TOKIO_THREAD_STACK_SIZE)
         .build()
         .unwrap();
 }
@@ -51,6 +45,9 @@ pub fn initialize() {
         let output_dir = format!("{}/tests/output/", crate_dir());
         std::fs::remove_dir_all(&output_dir).ok();
         std::fs::create_dir(&output_dir).expect("Failed to create output directory");
+
+        // Init logger
+        env_logger::init();
     });
 }
 
@@ -61,69 +58,87 @@ mod test_custom_specs {
     #[rstest(
         spec_name,
         tolerance,
-        case("custom/stacked_bar", 0.001),
-        case("custom/bar_colors", 0.001),
-        case("custom/imdb_histogram", 0.001),
-        case("custom/flights_crossfilter_a", 0.001),
-        case("custom/flights_crossfilter_csv", 0.001),
-        case("custom/log_scaled_histogram", 0.001),
-        case("custom/non_linear_histogram", 0.001),
-        case("custom/relative_frequency_histogram", 0.001),
-        case("custom/kde_iris", 0.001),
-        case("custom/2d_circles_histogram_imdb", 0.001),
-        case("custom/2d_histogram_imdb", 0.001),
-        case("custom/cumulative_window_imdb", 0.001),
-        case("custom/density_and_cumulative_histograms", 0.001),
-        case("custom/mean_strip_plot_movies", 0.001),
-        case("custom/table_heatmap_cars", 0.001),
-        case("custom/difference_from_mean", 0.001),
-        case("custom/nested_concat_align", 0.001),
-        case("custom/imdb_dashboard_cross_height", 0.001),
-        case("custom/stacked_bar_weather_year", 0.001),
-        case("custom/stacked_bar_weather_month", 0.001),
-        case("custom/stacked_bar_normalize", 0.001),
-        case("custom/layer_bar_labels_grey", 0.001),
-        case("custom/bar_month_temporal_initial", 0.001),
-        case("custom/selection_layer_bar_month", 0.001),
-        case("custom/interactive_layered_crossfilter", 0.001),
-        case("custom/interactive_seattle_weather", 0.001),
-        case("custom/concat_marginal_histograms", 0.001),
-        case("custom/joinaggregate_movie_rating", 0.001),
-        case("custom/joinaggregate_text_color_contrast", 0.001),
-        case("custom/cumulative_running_window", 0.001),
-        case("custom/point_bubble", 0.001),
-        case("custom/circle_bubble_health_income", 0.001),
-        case("custom/line_color_stocks", 0.001),
-        case("custom/line_slope_barley", 0.001),
-        case("custom/connected_scatterplot", 0.001),
-        case("custom/layer_line_co2_concentration", 0.001),
-        case("custom/window_rank_matches", 0.001),
-        case("custom/circle_github_punchcard", 0.001),
-        case("custom/rect_lasagna", 0.001),
-        case("custom/rect_heatmap_weather", 0.001),
-        case("custom/layer_line_rolling_mean_point_raw", 0.001),
-        case("custom/layer_histogram_global_mean", 0.001),
-        case("custom/layer_precipitation_mean", 0.001),
-        case("custom/wheat_wages", 0.001),
-        case("custom/trellis_stacked_bar", 0.001),
-        case("custom/trellis_bar_histogram", 0.001),
-        case("custom/interactive_average", 0.001),
-        case("custom/histogram_responsive", 0.001),
-        case("custom/grouped_bar_chart_with_error_bars", 0.001),
-        case("custom/one_dot_per_zipcode", 0.001),
-        case("custom/ridgeline", 0.001),
-        case("custom/binned_scatter", 0.001),
-        case("custom/seattle_temps_heatmap", 0.001),
-        case("custom/movies_agg_parameterize", 0.001),
-        case("custom/escaped_column_name1", 0.001),
-        case("custom/layered_movies", 0.001),
-        case("custom/shipping_mixed_scales", 0.001),
-        case("custom/datum_color", 0.001),
-        case("custom/bug_153", 0.001)
+        extract_inline_values,
+        case("custom/stacked_bar", 0.001, false),
+        case("custom/bar_colors", 0.001, false),
+        case("custom/imdb_histogram", 0.001, false),
+        case("custom/flights_crossfilter_a", 0.001, false),
+        case("custom/flights_crossfilter_csv", 0.001, false),
+        case("custom/log_scaled_histogram", 0.001, false),
+        case("custom/non_linear_histogram", 0.001, false),
+        case("custom/relative_frequency_histogram", 0.001, false),
+        case("custom/kde_iris", 0.001, false),
+        case("custom/2d_circles_histogram_imdb", 0.001, false),
+        case("custom/2d_histogram_imdb", 0.001, false),
+        case("custom/cumulative_window_imdb", 0.001, false),
+        case("custom/density_and_cumulative_histograms", 0.001, false),
+        case("custom/mean_strip_plot_movies", 0.001, false),
+        case("custom/table_heatmap_cars", 0.001, false),
+        case("custom/difference_from_mean", 0.001, false),
+        case("custom/nested_concat_align", 0.001, false),
+        case("custom/imdb_dashboard_cross_height", 0.001, false),
+        case("custom/stacked_bar_weather_year", 0.001, false),
+        case("custom/stacked_bar_weather_month", 0.001, false),
+        case("custom/stacked_bar_normalize", 0.001, false),
+        case("custom/layer_bar_labels_grey", 0.001, false),
+        case("custom/bar_month_temporal_initial", 0.001, false),
+        case("custom/selection_layer_bar_month", 0.001, false),
+        case("custom/interactive_layered_crossfilter", 0.001, false),
+        case("custom/interactive_seattle_weather", 0.001, false),
+        case("custom/concat_marginal_histograms", 0.001, false),
+        case("custom/joinaggregate_movie_rating", 0.001, false),
+        case("custom/joinaggregate_text_color_contrast", 0.001, false),
+        case("custom/cumulative_running_window", 0.001, false),
+        case("custom/point_bubble", 0.001, false),
+        case("custom/circle_bubble_health_income", 0.001, false),
+        case("custom/line_color_stocks", 0.001, false),
+        case("custom/line_slope_barley", 0.001, false),
+        case("custom/connected_scatterplot", 0.001, false),
+        case("custom/layer_line_co2_concentration", 0.001, false),
+        case("custom/window_rank_matches", 0.001, false),
+        case("custom/circle_github_punchcard", 0.001, false),
+        case("custom/rect_lasagna", 0.001, false),
+        case("custom/rect_heatmap_weather", 0.001, false),
+        case("custom/layer_line_rolling_mean_point_raw", 0.001, false),
+        case("custom/layer_histogram_global_mean", 0.001, false),
+        case("custom/layer_precipitation_mean", 0.001, false),
+        case("custom/wheat_wages", 0.001, false),
+        case("custom/trellis_stacked_bar", 0.001, false),
+        case("custom/trellis_bar_histogram", 0.001, false),
+        case("custom/interactive_average", 0.001, false),
+        case("custom/histogram_responsive", 0.001, false),
+        case("custom/grouped_bar_chart_with_error_bars", 0.001, false),
+        case("custom/one_dot_per_zipcode", 0.001, false),
+        case("custom/ridgeline", 0.001, false),
+        case("custom/binned_scatter", 0.001, false),
+        case("custom/seattle_temps_heatmap", 0.001, false),
+        case("custom/movies_agg_parameterize", 0.001, false),
+        case("custom/escaped_column_name1", 0.001, false),
+        case("custom/layered_movies", 0.001, false),
+        case("custom/shipping_mixed_scales", 0.001, false),
+        case("custom/datum_color", 0.001, false),
+        case("custom/bug_153", 0.001, false),
+        case("custom/period_in_field_name", 0.001, false),
+        case("custom/period_space_in_field_name", 0.001, false),
+        case("custom/pivot_tooltip1", 0.001, true),
+        case("custom/pivot_crash", 0.001, false),
+        case("custom/sorted_pivot_lines", 0.001, false),
+        case("custom/stacked_bar_initial_selection", 0.001, false),
+        case("custom/time_boolean_bug", 0.001, false),
+        case("custom/full_bin_histogram_selection", 0.001, false),
+        case("custom/datetime_scatter", 0.001, false),
+        case("custom/stack_divide_by_zero_error", 0.001, false),
+        case("custom/casestudy-us_population_pyramid_over_time", 0.001, true),
+        case("custom/sin_cos", 0.001, true),
+        case("custom/area_streamgraph", 0.001, true)
     )]
-    fn test_image_comparison(spec_name: &str, tolerance: f64) {
+    fn test_image_comparison(spec_name: &str, tolerance: f64, extract_inline_values: bool) {
         println!("spec_name: {}", spec_name);
-        TOKIO_RUNTIME.block_on(check_spec_sequence_from_files(spec_name, tolerance));
+        TOKIO_RUNTIME.block_on(check_spec_sequence_from_files(
+            spec_name,
+            tolerance,
+            extract_inline_values,
+        ));
         TOKIO_RUNTIME.block_on(check_pre_transform_spec_from_files(spec_name, tolerance));
     }
 
@@ -312,7 +327,7 @@ mod test_vega_specs {
     )]
     fn test_image_comparison(spec_name: &str, tolerance: f64) {
         println!("spec_name: {}", spec_name);
-        TOKIO_RUNTIME.block_on(check_spec_sequence_from_files(spec_name, tolerance));
+        TOKIO_RUNTIME.block_on(check_spec_sequence_from_files(spec_name, tolerance, false));
         TOKIO_RUNTIME.block_on(check_pre_transform_spec_from_files(spec_name, tolerance));
     }
 
@@ -370,10 +385,8 @@ mod test_vegalite_specs {
         case("vegalite/bar_column_fold", 0.001),
         case("vegalite/bar_column_pivot", 0.001),
         case("vegalite/bar_corner_radius_end", 0.001),
-
         // Different ordering of bars with the same length
         case("vegalite/bar_count_minimap", 0.1),
-
         case("vegalite/bar_custom_sort_full", 0.001),
         case("vegalite/bar_custom_sort_partial", 0.001),
         case("vegalite/bar_custom_time_domain", 0.001),
@@ -537,6 +550,7 @@ mod test_vegalite_specs {
         case("vegalite/interactive_layered_crossfilter", 0.001),
         case("vegalite/interactive_legend_dblclick", 0.001),
         case("vegalite/interactive_legend", 0.001),
+
         case("vegalite/interactive_line_brush_cursor", 0.001),
         case("vegalite/interactive_line_hover", 0.001),
 
@@ -886,7 +900,7 @@ mod test_vegalite_specs {
     )]
     fn test_image_comparison(spec_name: &str, tolerance: f64) {
         println!("spec_name: {}", spec_name);
-        TOKIO_RUNTIME.block_on(check_spec_sequence_from_files(spec_name, tolerance));
+        TOKIO_RUNTIME.block_on(check_spec_sequence_from_files(spec_name, tolerance, false));
         TOKIO_RUNTIME.block_on(check_pre_transform_spec_from_files(spec_name, tolerance));
     }
 
@@ -978,6 +992,7 @@ mod test_image_comparison_timeunit {
             watch_plan,
             &output_name,
             0.001,
+            false,
         ));
     }
 
@@ -1006,6 +1021,7 @@ mod test_image_comparison_agg {
             AggregateOpSpec::Variancep,
             AggregateOpSpec::Stdev,
             AggregateOpSpec::Stdevp,
+            AggregateOpSpec::Median,
         )]
         agg: AggregateOpSpec,
 
@@ -1048,6 +1064,7 @@ mod test_image_comparison_agg {
             watch_plan,
             &output_name,
             0.001,
+            false
         ));
     }
 
@@ -1118,6 +1135,7 @@ mod test_image_comparison_window {
             watch_plan,
             &output_name,
             0.001,
+            false,
         ));
     }
 
@@ -1158,6 +1176,7 @@ mod test_pre_transform_inline {
         let opts = PreTransformSpecOpts {
             row_limit: None,
             inline_datasets,
+            preserve_interactivity: true,
         };
         let request = PreTransformSpecRequest {
             spec: serde_json::to_string(&inline_spec).unwrap(),
@@ -1263,7 +1282,11 @@ fn write_updated_watch_plan(spec_name: &str, plan: &WatchPlan) {
     fs::write(watch_plan_path, serde_json::to_string_pretty(plan).unwrap()).unwrap()
 }
 
-async fn check_spec_sequence_from_files(spec_name: &str, tolerance: f64) {
+async fn check_spec_sequence_from_files(
+    spec_name: &str,
+    tolerance: f64,
+    extract_inline_values: bool,
+) {
     initialize();
 
     // Load spec
@@ -1275,7 +1298,15 @@ async fn check_spec_sequence_from_files(spec_name: &str, tolerance: f64) {
     // Load expected watch plan
     let watch_plan = load_expected_watch_plan(spec_name);
 
-    check_spec_sequence(full_spec, full_updates, watch_plan, spec_name, tolerance).await
+    check_spec_sequence(
+        full_spec,
+        full_updates,
+        watch_plan,
+        spec_name,
+        tolerance,
+        extract_inline_values,
+    )
+    .await
 }
 
 async fn check_pre_transform_spec_from_files(spec_name: &str, tolerance: f64) {
@@ -1283,7 +1314,7 @@ async fn check_pre_transform_spec_from_files(spec_name: &str, tolerance: f64) {
 
     // Load spec
     let full_spec = load_spec(spec_name);
-    println!("{:#?}", full_spec);
+    // println!("{:#?}", full_spec);
 
     let vegajs_runtime = vegajs_runtime();
 
@@ -1297,6 +1328,7 @@ async fn check_pre_transform_spec_from_files(spec_name: &str, tolerance: f64) {
     let opts = PreTransformSpecOpts {
         row_limit: None,
         inline_datasets: vec![],
+        preserve_interactivity: true,
     };
     let request = PreTransformSpecRequest {
         spec: serde_json::to_string(&full_spec).unwrap(),
@@ -1367,6 +1399,7 @@ async fn check_spec_sequence(
     watch_plan: WatchPlan,
     spec_name: &str,
     tolerance: f64,
+    extract_inline_data: bool,
 ) {
     // Initialize runtime
     let vegajs_runtime = vegajs_runtime();
@@ -1376,7 +1409,11 @@ async fn check_spec_sequence(
         default_input_tz: None,
     };
 
-    let spec_plan = SpecPlan::try_new(&full_spec, &Default::default()).unwrap();
+    let planner_config = PlannerConfig {
+        extract_inline_data,
+        ..Default::default()
+    };
+    let spec_plan = SpecPlan::try_new(&full_spec, &planner_config).unwrap();
 
     let task_scope = spec_plan.server_spec.to_task_scope().unwrap();
 
@@ -1386,10 +1423,10 @@ async fn check_spec_sequence(
     //     "client_spec: {}",
     //     serde_json::to_string_pretty(&spec_plan.client_spec).unwrap()
     // );
-    // println!(
-    //     "server_spec: {}",
-    //     serde_json::to_string_pretty(&spec_plan.server_spec).unwrap()
-    // );
+    println!(
+        "server_spec: {}",
+        serde_json::to_string_pretty(&spec_plan.server_spec).unwrap()
+    );
     //
     // println!(
     //     "comm_plan:\n---\n{}\n---",
@@ -1511,7 +1548,7 @@ async fn check_spec_sequence(
                 .map(|(scoped_var, value)| {
                     let json_value = match value {
                         TaskValue::Scalar(value) => value.to_json().unwrap(),
-                        TaskValue::Table(value) => value.to_json(),
+                        TaskValue::Table(value) => value.to_json().unwrap(),
                     };
                     ExportUpdate {
                         namespace: ExportUpdateNamespace::try_from(scoped_var.0.namespace())
